Module ui

Module ui 

Structs

UI

Enums

InternalEvent
NB: not totally comfortable with this event bus architecture; the loose coupling is convenient but it introduces non-deterministic delay, and feels overly general (over time I guess there will end up being too many enum variants.
Mode

Functions

reset