pub enum InternalEvent {
RegisterTask(JoinHandle<()>),
LogTweet(String),
LogError(Error),
}Expand description
NB: not totally comfortable with this event bus architecture; the loose coupling is convenient but it introduces non-deterministic delay, and feels overly general (over time I guess there will end up being too many enum variants.
Try to keep the scope limited to actually global events; for component-to-component events, consider directly coupling those pieces together.
Variants